Available sources
=================

.. autoclass:: layeredconfig.Defaults
  :members:
  :member-order: bysource

.. autoclass:: layeredconfig.Environment
  :members:
  :member-order: bysource

.. autoclass:: layeredconfig.Commandline
  :members:
  :member-order: bysource

.. autoclass:: layeredconfig.INIFile
  :members:
  :member-order: bysource

.. autoclass:: layeredconfig.JSONFile
  :members:
  :member-order: bysource

.. autoclass:: layeredconfig.YAMLFile
  :members:
  :member-order: bysource

.. autoclass:: layeredconfig.PListFile
  :members:
  :member-order: bysource

